@@ -8,7 +8,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -27,6 +27,7 @@
 #include "atom.h"
 #include "objprops.h"
 #include "document.h"
+#include "molecule.h"
 #include <glib/gi18n-lib.h>
 #include <cmath>
 #include <sstream>
@@ -56,6 +57,9 @@ Bond::Bond(Atom* first, Atom* last, unsigned char order): Object(BondType)
 
 Bond::~Bond()
 {
+	Molecule *mol = static_cast < Molecule * > (GetMolecule ());
+	if (mol)
+		mol->Remove (this);
 }
 
 Atom* Bond::GetAtom(int which) const
